
# Example 7.1:  Risk Approximations
 rm(list=ls())

###### specification of parameters and simulations
  mu =  0.1/252
  sigma = 0.3/sqrt(252)
  rho = 0.5
  n = 63

  w =  c(0.25, 0.25, 0.25, 0.25,     #5 portfolio weights  
         0, 0.50, 0.25, 0.25, 
         -0.5, 0.5,  0.5,  0.5, 
         -0.5, 0.5,  1.5, -0.5,
         -8,  25,  -7, -9)
  w = matrix(w, ncol=5)
                
  Sigma = matrix(rho, ncol=4, nrow=4)           #population covariance 
  diag(Sigma) = 1
  Sigma = sigma^2 * Sigma
  RiskTrue = diag(t(w)%*%Sigma%*%w)
  emax   = NULL
  errors = NULL
  EstRisks = 0                         #average risk
 
 for(k in 1:1000)
  {
  X = matrix(rnorm(5*n), ncol=5)
  X[,1:4] = sqrt(1 - rho) *X[,1:4] + sqrt(rho) * X[,5]
  X[,1:4] =  mu + sigma*X[,1:4]

  SamCov = var(X[,1:4])                         #sample cov
  tmp  = max(abs(Sigma-SamCov))                 #max error
  emax = c(emax, tmp)
  RiskEst  = diag(t(w)%*%SamCov%*%w)
  tmp  = abs(sqrt(RiskTrue) - sqrt(RiskEst))
  errors  = rbind(errors, tmp)
  EstRisks = EstRisks + sqrt(RiskEst)
  } 
 
 error = apply(errors, 2, mean)
 EstRisks = EstRisks/1000
 
 mean(emax)*100
 
 Results = rbind(sqrt(RiskTrue),  EstRisks, error)*sqrt(252)    #annualizaed
 Results = round(100*Results, 3) 
 Results


 postscript("Fig71.eps", width=4.4, height=4.8, horizontal=F, pointsize=8)
 par(mfrow = c(2,1), mar=c(4,2,2,1)+0.1, cex=0.8)
 
 matplot(1:n, X[,1:4], xlab="", ylab="", type = "l", lty=rep(1,4))
 title("A realization of daily returns of 4 assets")
 
 hist(emax*10000, main="distribution of maximum errors",xlab="10000*e_max")
   
 
 
